aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--tests/simple_abc9/abc9.v6
1 files changed, 3 insertions, 3 deletions
diff --git a/tests/simple_abc9/abc9.v b/tests/simple_abc9/abc9.v
index 7af2ace01..2752ff8cc 100644
--- a/tests/simple_abc9/abc9.v
+++ b/tests/simple_abc9/abc9.v
@@ -237,10 +237,10 @@ module abc9_test022
endmodule
// Citation: https://github.com/riscv/riscv-bitmanip
-// TODO: yosys -p "synth_xilinx -abc9 -top abc9_test024" abc9.v -q
+// TODO: yosys -p "synth_xilinx -abc9 -top abc9_test023" abc9.v -q
// returns before 14233843
-// Warning: Wire abc9_test024.\dout [1] is used but has no driver.
-module abc9_test024 #(
+// Warning: Wire abc9_test023.\dout [1] is used but has no driver.
+module abc9_test023 #(
parameter integer N = 2,
parameter integer M = 2
) (